## ABOUT

This is a mini deep learning framework created by cooper

cooper@Shanghai

## Features


+ Define Dynamic Computing-Graph
+ Define Neural Network Operator 
+ Define Linear,Sigmoid, L2_loss
+ Auto-Diff Computing
+ Auto-Feedforward and Backword

## Remain

+ Classification
+ Cross-Entropy
+ CNN,RNN

## Connection

wechat: 497464497

Mail : 497464497@qq.com


 